@@ -56,7 +56,7 @@ def filter_otus(frame:pd.DataFrame, taxa=False, low_abundance=False):
         
     return X, Taxa, Text
 
-def plot_umap(embedding_, l, Text, Taxa:None):
+def plot_umap(embedding_, l, Text, Taxa=None):
     #Dimensions 
     x = embedding_[:, 0]
     y = embedding_[:, 1]
@@ -78,7 +78,7 @@ def plot_umap(embedding_, l, Text, Taxa:None):
 
     TOOLS="hover,crosshair,pan,wheel_zoom,zoom_in,zoom_out,box_zoom,undo,redo,reset,tap,save,box_select,poly_select,lasso_select,"
             
-    if Taxa.empty():
+    if Taxa==None:
         dataE=dict(x=disk_x.tolist(),y=disk_y.tolist(),Color=colors,Name=Text.iloc[:,0].tolist())
         TOOLTIPS=[("Name", "@Name")]
     else:
